@@ -1,10 +1,8 @@
+;; -*- lexical-binding: t -*-
 
 (require 'ert)
+(require 'cl-lib)
 
-;; (require 'popup)
-
-;; for "every" function
-(require 'cl)
 (load-file "ws-butler.el")
 
 (defmacro ws-butler-test-with-test-buffer (&rest body)
@@ -28,9 +26,11 @@
   (ws-butler-test-with-common-setup
     (insert "a b c")
     (execute-kbd-macro (read-kbd-macro "M-DEL"))
-    (should (every #'identity (list 1 2 3)))
+    (should (cl-every #'identity (list 1 2 3)))
     (should (string-equal (buffer-string) "a b "))))
 
+(declare-function ws-butler-before-save "ws-butler")
+
 (ert-deftest ws-butler-test-trim-predicate ()
   "Tests `ws-butler-trim-predicate'."
   (ws-butler-test-with-common-setup
